@@ -27,7 +27,7 @@ class NormalMode
   : public BaseMode
 {
 public:
-  NormalMode( KigPart& );
+  explicit NormalMode( KigPart& );
   ~NormalMode();
 
   using BaseMode::midClicked;
@@ -50,7 +50,7 @@ protected:
 
 protected:
   /**
-   * Objcects were added..
+   * Objects were added.
    */
   void redrawScreen( KigWidget* ) Q_DECL_OVERRIDE;
 
