@@ -427,8 +427,9 @@ PythonScripter::PythonScripter()
 PythonScripter::~PythonScripter()
 {
   PyErr_Clear();
-  Py_Finalize();
   delete d;
+  // Py_FinalizeEx();
+  Py_Finalize();  // maintained for compatibility reasons with python2
 }
 
 class CompiledPythonScript::Private
